@@ -63,6 +63,9 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			return m, tea.Quit
 		case "left", "h", "ctrl+p", "tab",
 			"right", "l", "ctrl+n", "shift+tab":
+			if m.negative == "" {
+				break
+			}
 			m.confirmation = !m.confirmation
 		case "enter":
 			m.quitting = true
@@ -103,6 +106,11 @@ func (m model) View() string {
 		neg = m.selectedStyle.Render(m.negative + timeout)
 	}
 
+	// If the option is intentionally empty, do not show it.
+	if m.negative == "" {
+		neg = ""
+	}
+
 	return lipgloss.JoinVertical(lipgloss.Center, m.promptStyle.Render(m.prompt), lipgloss.JoinHorizontal(lipgloss.Left, aff, neg))
 }
 
