@@ -6,13 +6,16 @@ import (
 	"github.com/charmbracelet/gum/choose"
 	"github.com/charmbracelet/gum/completion"
 	"github.com/charmbracelet/gum/confirm"
+	"github.com/charmbracelet/gum/file"
 	"github.com/charmbracelet/gum/filter"
 	"github.com/charmbracelet/gum/format"
 	"github.com/charmbracelet/gum/input"
 	"github.com/charmbracelet/gum/join"
 	"github.com/charmbracelet/gum/man"
+	"github.com/charmbracelet/gum/pager"
 	"github.com/charmbracelet/gum/spin"
 	"github.com/charmbracelet/gum/style"
+	"github.com/charmbracelet/gum/table"
 	"github.com/charmbracelet/gum/write"
 )
 
@@ -54,6 +57,20 @@ type Gum struct {
 	//
 	Confirm confirm.Options `cmd:"" help:"Ask a user to confirm an action"`
 
+	// File provides an interface to pick a file from a folder (tree).
+	// The user is provided a file manager-like interface to navigate, to
+	// select a file.
+	//
+	// Let's pick a file from the current directory:
+	//
+	// $ gum file
+	// $ gum file .
+	//
+	// Let's pick a file from the home directory:
+	//
+	// $ gum file $HOME
+	File file.Options `cmd:"" help:"Pick a file from a folder"`
+
 	// Filter provides a fuzzy searching text input to allow filtering a list of
 	// options to select one option.
 	//
@@ -100,6 +117,25 @@ type Gum struct {
 	//
 	Join join.Options `cmd:"" help:"Join text vertically or horizontally"`
 
+	// Pager provides a shell script interface for the viewport bubble.
+	// https://github.com/charmbracelet/bubbles/tree/master/viewport
+	//
+	// It allows the user to scroll through content like a pager.
+	//
+	// ╭────────────────────────────────────────────────╮
+	// │    1 │ Gum Pager                               │
+	// │    2 │ =========                               │
+	// │    3 │                                         │
+	// │    4 │ ```                                     │
+	// │    5 │ gum pager --height 10 --width 25 < text │
+	// │    6 │ ```                                     │
+	// │    7 │                                         │
+	// │    8 │                                         │
+	// ╰────────────────────────────────────────────────╯
+	//  ↑/↓: Navigate • q: Quit
+	//
+	Pager pager.Options `cmd:"" help:"Scroll through a file"`
+
 	// Spin provides a shell script interface for the spinner bubble.
 	// https://github.com/charmbracelet/bubbles/tree/master/spinner
 	//
@@ -142,6 +178,23 @@ type Gum struct {
 	//
 	Style style.Options `cmd:"" help:"Apply coloring, borders, spacing to text"`
 
+	// Table provides a shell script interface for the table bubble.
+	// https://github.com/charmbracelet/bubbles/tree/master/table
+	//
+	// It is useful to render tabular (CSV) data in a terminal and allows
+	// the user to select a row from the table.
+	//
+	// Let's render a table of gum flavors:
+	//
+	// $ gum table <<< "Flavor,Price\nStrawberry,$0.50\nBanana,$0.99\nCherry,$0.75"
+	//
+	//  Flavor      Price
+	//  Strawberry  $0.50
+	//  Banana      $0.99
+	//  Cherry      $0.75
+	//
+	Table table.Options `cmd:"" help:"Render a table of data"`
+
 	// Write provides a shell script interface for the text area bubble.
 	// https://github.com/charmbracelet/bubbles/tree/master/textarea
 	//
