@@ -52,12 +52,22 @@ func main() {
 			Summary: false,
 		}),
 		kong.Vars{
-			"version":           version,
-			"defaultBackground": "",
-			"defaultForeground": "",
-			"defaultMargin":     "0 0",
-			"defaultPadding":    "0 0",
-			"defaultUnderline":  "false",
+			"version":                 version,
+			"defaultHeight":           "0",
+			"defaultWidth":            "0",
+			"defaultAlign":            "left",
+			"defaultBorder":           "none",
+			"defaultBorderForeground": "",
+			"defaultBorderBackground": "",
+			"defaultBackground":       "",
+			"defaultForeground":       "",
+			"defaultMargin":           "0 0",
+			"defaultPadding":          "0 0",
+			"defaultUnderline":        "false",
+			"defaultBold":             "false",
+			"defaultFaint":            "false",
+			"defaultItalic":           "false",
+			"defaultStrikethrough":    "false",
 		},
 	)
 	if err := ctx.Run(); err != nil {
